{% extends "article.html" %}

{% block imported_css %}
  <link rel="stylesheet"
        href="{{ base_url }}statics/pico_sans_plus.css" />
{% endblock imported_css %}

{% block extra_css %}
  {{ super() }}
  .article-body {
    border-left: none;
    padding-left: 0;
  }
  .aside h2, .aside hgroup {
    padding-right: 0;
  }
  .noprint {
    display: none;
  }
{% endblock extra_css %}

{% block extra_head %}
  <link href="{{ base_url }}statics/paged-interface-0.3.css" rel="stylesheet" type="text/css" />
  <script src="{{ base_url }}statics/paged-0.4.3.polyfill.min.js"></script>
{% endblock extra_head %}
